@@ -53,10 +53,12 @@ time_diff <- function(x, y, time_by = 1,
   num <- time_by_num(tby)
   if (time_by_is_num(tby)){
     set_time_cast(y, x)
-    if (!inherits(y, c("numeric", "integer"))){
+    if (!is.numeric(y)){
+    # if (!inherits(y, c("numeric", "integer"))){
       y <- time_as_number(y)
     }
-    if (!inherits(x, c("numeric", "integer"))){
+    if (!is.numeric(x)){
+    # if (!inherits(x, c("numeric", "integer"))){
       x <- time_as_number(x)
     }
     out <- (y - x) / num
